﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Diagnostics;

namespace HLWebPluginHost.PluginLib {

  /// <summary>
  /// Attribute to be implemented by all plugins to make them recognizeable by PluginHelper
  /// </summary>
  [AttributeUsage(AttributeTargets.Assembly)]
  public class HLWebPluginViewLocations : Attribute {
    public string[] viewLocations { get; set; }
    public bool addLink { get; set; }
    public string name { get; set; }
    public string controller { get; set; }
    public string action { get; set; }

    /// <summary>
    /// By declaring this custom attribute in a plugin, we can indicate to the host that the plugin assembly actually is  a plugin. 
    /// It will also let us pass information back to the host at runtime. 
    /// Currently, we will just be building a link on the plugin page, 
    /// but you could use the same technique to pass any type of information that a host may wish to know about its plugins.
    /// </summary>
    /// <param name="viewLocations"></param>
    /// <param name="addLink"></param>
    public HLWebPluginViewLocations(string[] viewLocations, bool addLink) {
      this.viewLocations = viewLocations;
      this.addLink = addLink;
    }
  }
}